==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/SAPApplicationServerInstanceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin

import com.pulumi.azurenative.workloads.SAPApplicationServerInstanceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Define the SAP Application Server Instance resource.
 * Azure REST API version: 2023-04-01. Prior API version in Azure Native 1.x: 2021-12-01-preview.
 * Other available API versions: 2021-12-01-preview, 2023-10-01-preview.
 * ## Example Usage
 * ### Create SAP Application Server Instances for HA System with Availability Set
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var sapApplicationServerInstance = new AzureNative.Workloads.SAPApplicationServerInstance("sapApplicationServerInstance", new()
 *     {
 *         ApplicationInstanceName = "app01",
 *         Location = "westcentralus",
 *         ResourceGroupName = "test-rg",
 *         SapVirtualInstanceName = "X00",
 *         Tags = null,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/workloads/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := workloads.NewSAPApplicationServerInstance(ctx, "sapApplicationServerInstance", &workloads.SAPApplicationServerInstanceArgs{
 * 			ApplicationInstanceName: pulumi.String("app01"),
 * 			Location:                pulumi.String("westcentralus"),
 * 			ResourceGroupName:       pulumi.String("test-rg"),
 * 			SapVirtualInstanceName:  pulumi.String("X00"),
 * 			Tags:                    nil,
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.workloads.SAPApplicationServerInstance;
 * import com.pulumi.azurenative.workloads.SAPApplicationServerInstanceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var sapApplicationServerInstance = new SAPApplicationServerInstance("sapApplicationServerInstance", SAPApplicationServerInstanceArgs.builder()
 *             .applicationInstanceName("app01")
 *             .location("westcentralus")
 *             .resourceGroupName("test-rg")
 *             .sapVirtualInstanceName("X00")
 *             .tags()
 *             .build());
 *     }
 * }
 * ```
 * ### SAPApplicationServerInstances_Create
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var sapApplicationServerInstance = new AzureNative.Workloads.SAPApplicationServerInstance("sapApplicationServerInstance", new()
 *     {
 *         ApplicationInstanceName = "app01",
 *         Location = "westcentralus",
 *         ResourceGroupName = "test-rg",
 *         SapVirtualInstanceName = "X00",
 *         Tags = null,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/workloads/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := workloads.NewSAPApplicationServerInstance(ctx, "sapApplicationServerInstance", &workloads.SAPApplicationServerInstanceArgs{
 * 			ApplicationInstanceName: pulumi.String("app01"),
 * 			Location:                pulumi.String("westcentralus"),
 * 			ResourceGroupName:       pulumi.String("test-rg"),
 * 			SapVirtualInstanceName:  pulumi.String("X00"),
 * 			Tags:                    nil,
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.workloads.SAPApplicationServerInstance;
 * import com.pulumi.azurenative.workloads.SAPApplicationServerInstanceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var sapApplicationServerInstance = new SAPApplicationServerInstance("sapApplicationServerInstance", SAPApplicationServerInstanceArgs.builder()
 *             .applicationInstanceName("app01")
 *             .location("westcentralus")
 *             .resourceGroupName("test-rg")
 *             .sapVirtualInstanceName("X00")
 *             .tags()
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:workloads:SAPApplicationServerInstance app01 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Workloads/sapVirtualInstances/{sapVirtualInstanceName}/applicationInstances/{applicationInstanceName}
 * ```
 * @property applicationInstanceName The name of SAP Application Server instance resource.
 * @property location The geo-location where the resource lives
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property sapVirtualInstanceName The name of the Virtual Instances for SAP solutions resource
 * @property tags Resource tags.
 */
public data class SAPApplicationServerInstanceArgs(
    public val applicationInstanceName: Output<String>? = null,
    public val location: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val sapVirtualInstanceName: Output<String>? = null,
    public val tags: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.SAPApplicationServerInstanceArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.SAPApplicationServerInstanceArgs =
        com.pulumi.azurenative.workloads.SAPApplicationServerInstanceArgs.builder()
            .applicationInstanceName(applicationInstanceName?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .sapVirtualInstanceName(sapVirtualInstanceName?.applyValue({ args0 -> args0 }))
            .tags(
                tags?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [SAPApplicationServerInstanceArgs].
 */
@PulumiTagMarker
public class SAPApplicationServerInstanceArgsBuilder internal constructor() {
    private var applicationInstanceName: Output<String>? = null

    private var location: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var sapVirtualInstanceName: Output<String>? = null

    private var tags: Output<Map<String, String>>? = null

    /**
     * @param value The name of SAP Application Server instance resource.
     */
    @JvmName("yqxwgnwahmtxwsei")
    public suspend fun applicationInstanceName(`value`: Output<String>) {
        this.applicationInstanceName = value
    }

    /**
     * @param value The geo-location where the resource lives
     */
    @JvmName("nsrmmfumlvejmgvx")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("ajtcsdikkuroirmk")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the Virtual Instances for SAP solutions resource
     */
    @JvmName("jtvymvgndkbaruny")
    public suspend fun sapVirtualInstanceName(`value`: Output<String>) {
        this.sapVirtualInstanceName = value
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("weruephngubjygco")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value The name of SAP Application Server instance resource.
     */
    @JvmName("drcnrqmoqrawiyne")
    public suspend fun applicationInstanceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.applicationInstanceName = mapped
    }

    /**
     * @param value The geo-location where the resource lives
     */
    @JvmName("tigomdgdnhmddwlf")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("wfnpwgmbtxkxvusa")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Virtual Instances for SAP solutions resource
     */
    @JvmName("dgqgtitnybajruwd")
    public suspend fun sapVirtualInstanceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sapVirtualInstanceName = mapped
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("pursdtdxuflgsqmw")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Resource tags.
     */
    @JvmName("rnlqjcrresdxvsov")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    internal fun build(): SAPApplicationServerInstanceArgs = SAPApplicationServerInstanceArgs(
        applicationInstanceName = applicationInstanceName,
        location = location,
        resourceGroupName = resourceGroupName,
        sapVirtualInstanceName = sapVirtualInstanceName,
        tags = tags,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/SAPApplicationServerInstanceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin

import com.pulumi.azurenative.workloads.SAPApplicationServerInstanceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Define the SAP Application Server Instance resource.
 * Azure REST API version: 2023-04-01. Prior API version in Azure Native 1.x: 2021-12-01-preview.
 * Other available API versions: 2021-12-01-preview, 2023-10-01-preview.
 * ## Example Usage
 * ### Create SAP Application Server Instances for HA System with Availability Set
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var sapApplicationServerInstance = new AzureNative.Workloads.SAPApplicationServerInstance("sapApplicationServerInstance", new()
 *     {
 *         ApplicationInstanceName = "app01",
 *         Location = "westcentralus",
 *         ResourceGroupName = "test-rg",
 *         SapVirtualInstanceName = "X00",
 *         Tags = null,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/workloads/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := workloads.NewSAPApplicationServerInstance(ctx, "sapApplicationServerInstance", &workloads.SAPApplicationServerInstanceArgs{
 * 			ApplicationInstanceName: pulumi.String("app01"),
 * 			Location:                pulumi.String("westcentralus"),
 * 			ResourceGroupName:       pulumi.String("test-rg"),
 * 			SapVirtualInstanceName:  pulumi.String("X00"),
 * 			Tags:                    nil,
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.workloads.SAPApplicationServerInstance;
 * import com.pulumi.azurenative.workloads.SAPApplicationServerInstanceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var sapApplicationServerInstance = new SAPApplicationServerInstance("sapApplicationServerInstance", SAPApplicationServerInstanceArgs.builder()
 *             .applicationInstanceName("app01")
 *             .location("westcentralus")
 *             .resourceGroupName("test-rg")
 *             .sapVirtualInstanceName("X00")
 *             .tags()
 *             .build());
 *     }
 * }
 * ```
 * ### SAPApplicationServerInstances_Create
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var sapApplicationServerInstance = new AzureNative.Workloads.SAPApplicationServerInstance("sapApplicationServerInstance", new()
 *     {
 *         ApplicationInstanceName = "app01",
 *         Location = "westcentralus",
 *         ResourceGroupName = "test-rg",
 *         SapVirtualInstanceName = "X00",
 *         Tags = null,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/workloads/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := workloads.NewSAPApplicationServerInstance(ctx, "sapApplicationServerInstance", &workloads.SAPApplicationServerInstanceArgs{
 * 			ApplicationInstanceName: pulumi.String("app01"),
 * 			Location:                pulumi.String("westcentralus"),
 * 			ResourceGroupName:       pulumi.String("test-rg"),
 * 			SapVirtualInstanceName:  pulumi.String("X00"),
 * 			Tags:                    nil,
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.workloads.SAPApplicationServerInstance;
 * import com.pulumi.azurenative.workloads.SAPApplicationServerInstanceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var sapApplicationServerInstance = new SAPApplicationServerInstance("sapApplicationServerInstance", SAPApplicationServerInstanceArgs.builder()
 *             .applicationInstanceName("app01")
 *             .location("westcentralus")
 *             .resourceGroupName("test-rg")
 *             .sapVirtualInstanceName("X00")
 *             .tags()
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:workloads:SAPApplicationServerInstance app01 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Workloads/sapVirtualInstances/{sapVirtualInstanceName}/applicationInstances/{applicationInstanceName}
 * ```
 * @property applicationInstanceName The name of SAP Application Server instance resource.
 * @property location The geo-location where the resource lives
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property sapVirtualInstanceName The name of the Virtual Instances for SAP solutions resource
 * @property tags Resource tags.
 */
public data class SAPApplicationServerInstanceArgs(
    public val applicationInstanceName: Output<String>? = null,
    public val location: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val sapVirtualInstanceName: Output<String>? = null,
    public val tags: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.SAPApplicationServerInstanceArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.SAPApplicationServerInstanceArgs =
        com.pulumi.azurenative.workloads.SAPApplicationServerInstanceArgs.builder()
            .applicationInstanceName(applicationInstanceName?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .sapVirtualInstanceName(sapVirtualInstanceName?.applyValue({ args0 -> args0 }))
            .tags(
                tags?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [SAPApplicationServerInstanceArgs].
 */
@PulumiTagMarker
public class SAPApplicationServerInstanceArgsBuilder internal constructor() {
    private var applicationInstanceName: Output<String>? = null

    private var location: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var sapVirtualInstanceName: Output<String>? = null

    private var tags: Output<Map<String, String>>? = null

    /**
     * @param value The name of SAP Application Server instance resource.
     */
    @JvmName("adcsbolkywkurvae")
    public suspend fun applicationInstanceName(`value`: Output<String>) {
        this.applicationInstanceName = value
    }

    /**
     * @param value The geo-location where the resource lives
     */
    @JvmName("figjjalejaicdbxb")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("rimknsnvafgtrwyh")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the Virtual Instances for SAP solutions resource
     */
    @JvmName("shnajbafbfnnvmga")
    public suspend fun sapVirtualInstanceName(`value`: Output<String>) {
        this.sapVirtualInstanceName = value
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("qwnqihyvnfufpxpm")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value The name of SAP Application Server instance resource.
     */
    @JvmName("hgguokqyctnmajdo")
    public suspend fun applicationInstanceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.applicationInstanceName = mapped
    }

    /**
     * @param value The geo-location where the resource lives
     */
    @JvmName("eouhmcvhbwhyqeal")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("liervwuyrjkemlrv")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Virtual Instances for SAP solutions resource
     */
    @JvmName("dverelwgrbtuywpt")
    public suspend fun sapVirtualInstanceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sapVirtualInstanceName = mapped
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("xgliqsyyryvtwiag")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Resource tags.
     */
    @JvmName("mwwvlcwmoilqocmr")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    internal fun build(): SAPApplicationServerInstanceArgs = SAPApplicationServerInstanceArgs(
        applicationInstanceName = applicationInstanceName,
        location = location,
        resourceGroupName = resourceGroupName,
        sapVirtualInstanceName = sapVirtualInstanceName,
        tags = tags,
    )
}
